@@ -158,8 +158,6 @@ namespace NppDarkMode
 	HPEN getHotEdgePen();
 	HPEN getDisabledEdgePen();
 
-	COLORREF getIndividualTabColour(int colourIndex, bool themeDependant, bool saturated);
-
 	void setBackgroundColor(COLORREF c);
 	void setSofterBackgroundColor(COLORREF c);
 	void setHotBackgroundColor(COLORREF c);
@@ -228,7 +226,9 @@ namespace NppDarkMode
 
 	void disableVisualStyle(HWND hwnd, bool doDisable);
 	void calculateTreeViewStyle();
-	void setTreeViewStyle(HWND hwnd);
+	void updateTreeViewStylePrev();
+	TreeViewStyle getTreeViewStyle();
+	void setTreeViewStyle(HWND hWnd, bool force = false);
 	bool isThemeDark();
 	void setBorder(HWND hwnd, bool border = true);
 
