@@ -62,7 +62,8 @@ intptr_t CALLBACK AboutDlg::run_dlgProc(UINT message, WPARAM wParam, LPARAM lPar
             //_pageLink.create(::GetDlgItem(_hSelf, IDC_AUTHOR_NAME), L"https://notepad-plus-plus.org/news/v87-about-taiwan/");
             
 			_pageLink.init(_hInst, _hSelf);
-            _pageLink.create(::GetDlgItem(_hSelf, IDC_HOME_ADDR), L"https://notepad-plus-plus.org/");
+            //_pageLink.create(::GetDlgItem(_hSelf, IDC_HOME_ADDR), L"https://notepad-plus-plus.org/");
+			_pageLink.create(::GetDlgItem(_hSelf, IDC_AUTHOR_NAME), L"https://notepad-plus-plus.org/news/v878-we-are-with-ukraine/");
 
 			return TRUE;
 		}
@@ -108,7 +109,8 @@ intptr_t CALLBACK AboutDlg::run_dlgProc(UINT message, WPARAM wParam, LPARAM lPar
 			const int iconSize = _dpiManager.scale(80);
 			if (_hIcon == nullptr)
 			{
-				DPIManagerV2::loadIcon(_hInst, MAKEINTRESOURCE(NppDarkMode::isEnabled() ? IDI_CHAMELEON_DM : IDI_CHAMELEON), iconSize, iconSize, &_hIcon);
+				//DPIManagerV2::loadIcon(_hInst, MAKEINTRESOURCE(NppDarkMode::isEnabled() ? IDI_CHAMELEON_DM : IDI_CHAMELEON), iconSize, iconSize, &_hIcon);
+				DPIManagerV2::loadIcon(_hInst, MAKEINTRESOURCE(IDI_WITHUKRAINE), iconSize, iconSize, &_hIcon);
 				//DPIManagerV2::loadIcon(_hInst, MAKEINTRESOURCE(NppDarkMode::isEnabled() ? IDI_TAIWANSSOVEREIGNTY_DM : IDI_TAIWANSSOVEREIGNTY), iconSize, iconSize, &_hIcon);
 			}
 
@@ -230,6 +232,83 @@ intptr_t CALLBACK DebugInfoDlg::run_dlgProc(UINT message, WPARAM wParam, LPARAM
 			_debugInfoStr += nppGui.isSnapshotMode() ? L"ON" : L"OFF";
 			_debugInfoStr += L"\r\n";
 
+			// Placeholders
+			_debugInfoStr += L"Placeholders : ";
+			_debugInfoStr += nppGui._keepSessionAbsentFileEntries ? L"ON" : L"OFF";
+			_debugInfoStr += L"\r\n";
+
+			// SC_TECHNOLOGY
+			_debugInfoStr += L"Scintilla Rendering Mode : ";
+			switch (nppGui._writeTechnologyEngine)
+			{
+				case defaultTechnology:
+					_debugInfoStr += L"SC_TECHNOLOGY_DEFAULT (0)";
+					break;
+				case directWriteTechnology:
+					_debugInfoStr += L"SC_TECHNOLOGY_DIRECTWRITE (1)";
+					break;
+				case directWriteRetainTechnology:
+					_debugInfoStr += L"SC_TECHNOLOGY_DIRECTWRITERETAIN (2)";
+					break;
+				case directWriteDcTechnology:
+					_debugInfoStr += L"SC_TECHNOLOGY_DIRECTWRITEDC (3)";
+					break;
+				case directWriteDX11Technology:
+					_debugInfoStr += L"SC_TECHNOLOGY_DIRECT_WRITE_1 (4)";
+					break;
+				case directWriteTechnologyUnavailable:
+					_debugInfoStr += L"DirectWrite Technology Unavailable (5, same as SC_TECHNOLOGY_DEFAULT)";
+					break;
+				default:
+					_debugInfoStr += L"unknown (" + std::to_wstring(nppGui._writeTechnologyEngine) + L")";
+			}
+			_debugInfoStr += L"\r\n";
+
+			// Multi-instance
+			_debugInfoStr += L"Multi-instance Mode : ";
+			switch (nppGui._multiInstSetting)
+			{
+				case monoInst:
+					_debugInfoStr += L"monoInst";
+					break;
+				case multiInstOnSession:
+					_debugInfoStr += L"multiInstOnSession";
+					break;
+				case multiInst:
+					_debugInfoStr += L"multiInst";
+					break;
+				default:
+					_debugInfoStr += L"unknown(" + std::to_wstring(nppGui._multiInstSetting) + L")";
+			}
+			_debugInfoStr += L"\r\n";
+
+			// File Status Auto-Detection
+			_debugInfoStr += L"File Status Auto-Detection : ";
+			if (nppGui._fileAutoDetection == cdDisabled)
+			{
+				_debugInfoStr += L"cdDisabled";
+			}
+			else
+			{
+				if (nppGui._fileAutoDetection & cdEnabledOld)
+					_debugInfoStr += L"cdEnabledOld (for all opened files/tabs)";
+				else if (nppGui._fileAutoDetection & cdEnabledNew)
+					_debugInfoStr += L"cdEnabledNew (for current file/tab only)";
+				else
+					_debugInfoStr += L"cdUnknown (?!)";
+
+				if (nppGui._fileAutoDetection & cdAutoUpdate)
+					_debugInfoStr += L" + cdAutoUpdate";
+				if (nppGui._fileAutoDetection & cdGo2end)
+					_debugInfoStr += L" + cdGo2end";
+			}
+			_debugInfoStr += L"\r\n";
+
+			// Dark Mode
+			_debugInfoStr += L"Dark Mode : ";
+			_debugInfoStr += nppGui._darkmode._isEnabled ? L"ON" : L"OFF";
+			_debugInfoStr += L"\r\n";
+
 			// OS information
 			HKEY hKey = nullptr;
 			DWORD dataSize = 0;
