@@ -215,7 +215,7 @@
 	#define	IDC_HISTORY_GB_STATIC (IDD_PREFERENCE_SUB_MISC + 4)
 	#define	IDC_CHECK_DONTCHECKHISTORY (IDD_PREFERENCE_SUB_MISC + 5)
 	#define	IDC_MAXNBFILE_STATIC (IDD_PREFERENCE_SUB_MISC + 6)
-	#define	IDC_COMBO_SYSTRAY_ACTION_HOICE (IDD_PREFERENCE_SUB_MISC + 7)
+	#define	IDC_COMBO_SYSTRAY_ACTION_CHOICE (IDD_PREFERENCE_SUB_MISC + 7)
 	#define	IDC_SYSTRAY_STATIC (IDD_PREFERENCE_SUB_MISC + 8)
 	#define	IDC_CHECK_REMEMBERSESSION (IDD_PREFERENCE_SUB_MISC + 9)
 	#define	IDC_INDENTUSING_STATIC (IDD_PREFERENCE_SUB_MISC + 10)
@@ -267,6 +267,9 @@
 	#define	IDC_CHECK_MUTE_SOUNDS (IDD_PREFERENCE_SUB_MISC + 60)
 	#define	IDC_CHECK_SAVEALLCONFIRM (IDD_PREFERENCE_SUB_MISC + 61)
 
+	#define	IDC_COMBO_SC_TECHNOLOGY_CHOICE (IDD_PREFERENCE_SUB_MISC + 62)
+	#define	IDC_SC_TECHNOLOGY_STATIC (IDD_PREFERENCE_SUB_MISC + 63)
+
 #define	IDD_PREFERENCE_SUB_NEWDOCUMENT 6400 //(IDD_PREFERENCE_BOX + 400)
 	#define	IDC_FORMAT_GB_STATIC (IDD_PREFERENCE_SUB_NEWDOCUMENT + 1)
 	#define	IDC_RADIO_F_WIN (IDD_PREFERENCE_SUB_NEWDOCUMENT + 2)
